/*
 * Copyright (C) 2013 Jaume Roca
 *
 * This programn is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with Gnome Documents; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Author: Jaume Roca <jaumedevalls@gmail.com>
 *
 */
const St = imports.gi.St;
const Main = imports.ui.main;
const Clutter=imports.gi.Clutter;
const Shell = imports.gi.Shell;
const PopupMenu = imports.ui.popupMenu;
const PanelMenu = imports.ui.panelMenu;
const GLib = imports.gi.GLib;
const Mainloop = imports.mainloop;

let button, extensionPath, loopCall, birthdays;

function BirthdayButton() {
    this._init();
};

BirthdayButton.prototype = {
    __proto__: PanelMenu.Button.prototype,
	lines: null,

    _init: function() {
		try {
		    PanelMenu.Button.prototype._init.call(this, 0.0);
		    this._label = new St.Bin({ style_class: 'panel-button', reactive: true,
		                      can_focus: true,
		                      x_fill:true,
		                      y_fill: false,
		                      track_hover:true
		                      });
		    this._box = new St.BoxLayout();

		    this._icon_disable=Clutter.Texture.new_from_file(extensionPath+"/icons/cake_disable.png");
			this._icon_enable=Clutter.Texture.new_from_file(extensionPath+"/icons/cake_enable.png");
			this._icon = this._icon_disable;
			this._box.insert_child_at_index(this._icon_disable,1);
			this._box.insert_child_at_index(this._icon_enable,1);
			this.text = new St.Label({text: "(0)" });
			this._box.insert_child_at_index(this.text,2);
			this._label.set_child(this._box);

		    this.actor.add_actor(this._label);			
		} catch (err) {
			global.log("Button init"+ err.message);
		}
    },

    setIcon : function (n) {
		try{
			if (n==0){
				this._icon=this._icon_disable.show();
				this._icon=this._icon_enable.hide();
			}
			else{
				this._icon=this._icon_enable.show();
				this._icon=this._icon_disable.hide();
			}
		} catch (err) {
			global.log("Button setIcons"+ err.message);
		}
	},

    setText : function (text) {
		try{
			this.text.set_text(text);
		} catch (err) {
			global.log("Button setText"+ err.message);
		}		
	},

    addMenuItem : function (text) {
		try{
		    this._myMenu = new PopupMenu.PopupMenuItem(_(text));
		    this.menu.addMenuItem(this._myMenu);
		} catch (err) {
			global.log("Button addMenuItem"+ err.message);
		}		
	},

    checkBirthdays : function (Path) {
		try{
			this.menu.removeAll();
			birthdays=0;
			let data = new Date();
			let dia = data.getDate();
			let mes = data.getMonth()+1;
			let content = Shell.get_file_contents_utf8_sync(Path);
			this.lines = content.toString().split('\n');
			//-1 because the last line is the file stats.
			for (let i = 0; i < this.lines.length -1; i++) {
				if (this.lines[i].substr(0,1)!="#"){
					if (this.lines[i].substr(0,2)==dia && this.lines[i].substr(3,2)==mes){
						this.addMenuItem(this.lines[i]);
						birthdays++;
					}
				}
			}
			this.setText("("+birthdays+")");
			if (birthdays > 0) {				
				this.setIcon(1);
			}
			else{
				this.setIcon(0);
			}
		} catch (err) {
			global.log("Button checkBirthdays"+ err.message);
		}
	},

	_onDestroy: function() {}
};

function init(extensionMeta) {
	try{
		extensionPath=extensionMeta.path;
	}
	catch (err) {
		global.log("init Error"+err.message);
	}
}

function checkBirthdaysLoop(){
	try{
		button.checkBirthdays(extensionPath+"/birthdays");
		return true;
	}
	catch (err) {
		global.log("checkBirthdaysLoop Error"+err.message);
	}
}

function enable() {
	try{
	   	button=new BirthdayButton();
		button.setIcon(0);
		Main.panel.addToStatusArea('birthday-notify',button,0,'right');
		button.checkBirthdays(extensionPath+"/birthdays");
		loopCall = GLib.timeout_add_seconds(0,60,checkBirthdaysLoop);
	}
	catch (err) {
		global.log("enable Error"+err.message);
	}
}

function disable() {
	try{
		button.destroy();
		Mainloop.source_remove(loopCall);
	}
	catch (err) {
		global.log("disable Error"+err.message);
	}
}
